==> 0.6.3rc1.zip: dmdirc-client/test/com/dmdirc/harness/TestConfigManagerMap.java <==
/*
 * Copyright (c) 2006-2010 Chris Smith, Shane Mc Cormack, Gregory Holmes
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc.harness;

import com.dmdirc.config.ConfigManager;
import java.util.HashMap;
import java.util.Map;

public class TestConfigManagerMap extends ConfigManager {
    private static final long serialVersionUID = 3604727894041756961L;

    public final Map<String, String> settings =
            new HashMap<String, String>();

    public TestConfigManagerMap() {
        super("", "", "", "");
    }

    @Override
    public String getOption(String domain, String option) {
        if (settings.containsKey(domain + "." + option)) {
            return settings.get(domain + "." + option);
        } else {
            return super.getOption(domain, option);
        }
    }

    @Override @Deprecated
    public boolean hasOption(String domain, String option) {
        if (settings.containsKey(domain + "." + option)) {
            return true;
        } else {
            return super.hasOption(domain, option);
        }
    }
}

==> 0.6.6b1.zip: dmdirc-client/test/com/dmdirc/harness/TestConfigManagerMap.java <==
/*
 * Copyright (c) 2006-2011 DMDirc Developers
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc.harness;

import com.dmdirc.config.ConfigManager;
import com.dmdirc.util.validators.Validator;
import java.util.HashMap;
import java.util.Map;

public class TestConfigManagerMap extends ConfigManager {
    private static final long serialVersionUID = 3604727894041756961L;

    public final Map<String, String> settings =
            new HashMap<String, String>();

    public TestConfigManagerMap() {
        super("", "", "", "");
    }

    @Override
    public String getOption(String domain, String option) {
        if (settings.containsKey(domain + "." + option)) {
            return settings.get(domain + "." + option);
        } else {
            return super.getOption(domain, option);
        }
    }

    @Override @Deprecated
    public boolean hasOption(String domain, String option, Validator<String> validator) {
        if (settings.containsKey(domain + "." + option)) {
            return true;
        } else {
            return super.hasOption(domain, option, validator);
        }
    }
}
